@@ -23,15 +23,15 @@ fi
 config etc/rc.d/rc.hald.new
 config etc/dbus-1/system.d/hal.conf.new
 
-( cd usr/doc/hal-0.5.9.1 ; rm -rf libhal )
-( cd usr/doc/hal-0.5.9.1 ; ln -sf ../../share/gtk-doc/html/libhal libhal )
-( cd usr/doc/hal-0.5.9.1 ; rm -rf libhal-storage )
-( cd usr/doc/hal-0.5.9.1 ; ln -sf ../../share/gtk-doc/html/libhal-storage libhal-storage )
-( cd usr/lib ; rm -rf libhal-storage.so )
-( cd usr/lib ; ln -sf libhal-storage.so.1.0.0 libhal-storage.so )
-( cd usr/lib ; rm -rf libhal-storage.so.1 )
-( cd usr/lib ; ln -sf libhal-storage.so.1.0.0 libhal-storage.so.1 )
 ( cd usr/lib ; rm -rf libhal.so.1 )
 ( cd usr/lib ; ln -sf libhal.so.1.0.0 libhal.so.1 )
 ( cd usr/lib ; rm -rf libhal.so )
 ( cd usr/lib ; ln -sf libhal.so.1.0.0 libhal.so )
+( cd usr/lib ; rm -rf libhal-storage.so.1 )
+( cd usr/lib ; ln -sf libhal-storage.so.1.0.0 libhal-storage.so.1 )
+( cd usr/lib ; rm -rf libhal-storage.so )
+( cd usr/lib ; ln -sf libhal-storage.so.1.0.0 libhal-storage.so )
+( cd usr/doc/hal-0.5.10 ; rm -rf libhal )
+( cd usr/doc/hal-0.5.10 ; ln -sf ../../share/gtk-doc/html/libhal libhal )
+( cd usr/doc/hal-0.5.10 ; rm -rf libhal-storage )
+( cd usr/doc/hal-0.5.10 ; ln -sf ../../share/gtk-doc/html/libhal-storage libhal-storage )
